@@ -3,21 +3,18 @@
 {-# LANGUAGE MonoLocalBinds #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE ExistentialQuantification #-}
+{- HLINT ignore "Use newtype instead of data" -}
 
 
 module Test.MockCat.Internal.Registry.Core
   ( attachVerifierToFn
   , lookupVerifierForFn
   , attachDynamicVerifierToFn
-  , createOverlay
-  , installOverlay
-  , clearOverlay
   , registerUnitMeta
   , lookupUnitMeta
   , UnitMeta
   , withUnitGuard
   , withAllUnitGuards
-  , markUnitUsed
   , isGuardActive
   , getLastRecorder
   , getLastRecorderRaw
@@ -153,8 +150,6 @@ clearThreadWithMockContext = do
   tid <- myThreadId
   atomically $ modifyTVar' threadWithMockStore (Map.delete tid)
 
-
-
 attachVerifierToFn ::
   forall fn params.
   (Typeable (InvocationRecorder params)) =>
@@ -181,15 +176,7 @@ lookupVerifierForFn fn = do
       
   case mbMatch of
     Just match -> pure [match]
-    Nothing -> do
-      -- 2. Fallback: return thread's mock history
-      --    This handles case where StableName is unstable (e.g. HPC enabled)
-      tid <- myThreadId
-      atomically $ do
-        hist <- readTVar threadMockHistory
-        case Map.lookup tid hist of
-           Nothing -> pure []
-           Just list -> pure list
+    Nothing -> pure []
 
 attachDynamicVerifierToFn :: forall fn. fn -> (Maybe MockName, Dynamic) -> IO ()
 attachDynamicVerifierToFn fn (name, payload) = do
@@ -223,17 +210,10 @@ findMatch target  (entry : rest)
   | sameFnStable target (stableFnName entry) = Just (mockName entry, entryPayload entry)
   | otherwise = findMatch target rest
 
-
-
-
-
-
-
 type UnitStableName = SomeStableName
 
 data UnitMeta = UnitMeta
   { unitGuardRef :: TVar Bool
-  , unitUsedRef :: TVar Bool
   }
 
 data UnitEntry = UnitEntry !UnitStableName !UnitMeta
@@ -255,22 +235,6 @@ type UnitRegistry = IntMap [UnitEntry]
 unitRegistry :: TVar UnitRegistry
 unitRegistry = (unsafePerformIO $ newTVarIO IntMap.empty) :: TVar UnitRegistry
 
--- | Per-run overlay registry (optional).
-data Overlay = Overlay
-
--- | Run the given IO action with a per-run overlay registry active.
--- The overlay is cleaned up after the action completes.
-createOverlay :: IO Overlay
-createOverlay = pure Overlay
-
-installOverlay :: Overlay -> IO ()
-installOverlay _ = pure ()
-
-clearOverlay :: IO ()
-clearOverlay = pure ()
-
-
-
 registerUnitMeta :: TVar ref -> IO UnitMeta
 registerUnitMeta ref = do
   stable <- makeStableName ref
@@ -308,17 +272,13 @@ withUnitGuard meta =
 withAllUnitGuards :: IO a -> IO a
 withAllUnitGuards = bracket_ (setAllUnitGuards True) (setAllUnitGuards False)
 
-markUnitUsed :: UnitMeta -> IO ()
-markUnitUsed meta = atomically $ writeTVar (unitUsedRef meta) True
-
 isGuardActive :: UnitMeta -> IO Bool
-isGuardActive meta = readTVarIO (unitGuardRef meta)
+isGuardActive (UnitMeta guardRef) = readTVarIO guardRef
 
 createUnitMeta :: IO UnitMeta
 createUnitMeta = do
   guardRef <- newTVarIO False
-  usedRef <- newTVarIO False
-  pure UnitMeta {unitGuardRef = guardRef, unitUsedRef = usedRef}
+  pure $ UnitMeta guardRef
 
 findUnit :: UnitStableName -> [UnitEntry] -> Maybe UnitMeta
 findUnit _ [] = Nothing
@@ -332,5 +292,3 @@ setAllUnitGuards flag =
     store <- readTVar unitRegistry
     forM_ (concat (IntMap.elems store)) $ \entry ->
       writeTVar (unitGuardRef (unitEntryMeta entry)) flag
-
-
