@@ -6,9 +6,13 @@ module Test.MockCat.WithMockIOSpec (spec) where
 import Test.Hspec
 import Test.MockCat
 import Control.Exception (try, ErrorCall(..), SomeException)
-import Control.Concurrent (forkIO)
+import Control.Concurrent (forkIO, threadDelay)
 import Control.Concurrent.MVar (newEmptyMVar, putMVar, takeMVar)
-import Control.Monad (void)
+import Control.Concurrent.Async (async, wait)
+import Control.Monad (void, forM_, replicateM)
+import Control.Monad.IO.Class (liftIO)
+import Control.Monad.IO.Unlift (withRunInIO)
+import Prelude hiding (any)
 
 spec :: Spec
 spec = do
@@ -53,3 +57,19 @@ spec = do
       case childRes of
         Left e -> show e `shouldContain` "No WithMockContext found"
         Right _ -> fail "Child thread should not have accessed parent context"
+    
+    it "stress test: many threads with many calls" $ do
+      let threads = 20 :: Int
+          callsPerThread = 10 :: Int
+          total = threads * callsPerThread :: Int
+
+      withMockIO $ do
+        mockFn <- mockM (any @String ~> True)
+          `expects` called (times total)
+
+        withRunInIO $ \runInIO -> do
+          as <- replicateM threads (async $ runInIO $ do
+              forM_ [1 .. callsPerThread] $ \_ -> do
+                void $ mockFn "stress"
+                liftIO $ threadDelay 1)
+          mapM_ wait as
\ No newline at end of file
